//Import unfolding map library
import de.fhpotsdam.unfolding.*;
import de.fhpotsdam.unfolding.geo.*;
import de.fhpotsdam.unfolding.utils.*;
import de.fhpotsdam.unfolding.providers.*;

//for remove duplicate numbers
import java.util.*;

//Control P5 Library
import controlP5.*;
ControlP5 cp5;

//Layout setting
final int leftMargin = 120;
final int rectWidth = 100;
final int rectHeight = 20;

final String keyword = "China";
final int groupNumber = 25;
final int topNumber = 100; //determine how many tags to be shown on the screen, but it's only a range
final int keywordNumber = 30;//this is actuall determine how many tags to be shown on the screen
final int imgLimit = 20;
final int maxTagNumber = 5;
final float frameLength = 20;

//the postion of user info on the right side
final int marginY = 350;
final int lineDist = 50;

//font
PFont font, fontInput;

int count = 0;
int maxImageNumber = imgLimit * groupNumber;

PImage[] img;
float[] lat,lon;
String[][] tagName;
int[] tagNumber;
int[][] tagCount; // get the popularity of the tag
String[] sortCount; 
int[] finalCount;
String[] selectedTag;

//this section is for user info
String[] userId;
String[] name;
PImage[] profileImg;
int[] posts;
int[] follows;
int[] followedBy;
int maxPosts;
int maxFollowInfo;
int[] imgOrder;
int selectedImageID;

//setup for map library
UnfoldingMap map;
Location[] loc;
ScreenPosition[] pos;
//setup for map library

void setup(){
  size(1300,1000,P2D);
  
  //GUI
  cp5 = new ControlP5(this);
       
  //setup for map library
  map = new UnfoldingMap(this, "map", leftMargin, 0, height, height, true, false, new Google.GoogleSimplified2Provider());
  MapUtils.createDefaultEventDispatcher(this, map);
  loc = new Location[maxImageNumber];
  pos = new ScreenPosition[maxImageNumber];
  //setup for map library
  
  img = new PImage[maxImageNumber];
  lat = new float[maxImageNumber];
  lon = new float[maxImageNumber];
  tagName = new String[maxImageNumber][maxTagNumber];
  tagNumber = new int[maxImageNumber];
  tagCount = new int[maxImageNumber][maxTagNumber];
  sortCount = new String[0];
  finalCount = new int[0];
  selectedTag = new String[keywordNumber];
  
  //this section is for user info
  userId = new String[maxImageNumber];
  name = new String[maxImageNumber];
  profileImg = new PImage[maxImageNumber];
  posts = new int[maxImageNumber];
  follows = new int[maxImageNumber];
  followedBy = new int[maxImageNumber];
  imgOrder = new int[0];
  
  //font
  font = loadFont("AvenirNext-Regular-24.vlw");
  fontInput = loadFont("AvenirNext-Regular-12.vlw");
  
  //GUI Setup
  cp5.addTextfield("Keyword")
   .setPosition(height + leftMargin + 18, 110)
   .setSize(148,20)
   .setFont(fontInput)
   .setColor(color(#1A1A1A)) //the font color
   .setColorForeground(color(#06AED6, 80)) // the frame color
   .setColorBackground(color(#06AED6, 50)) // the inside color
   .setColorLabel(color(#1A1A1A))
   .setAutoClear(false)
   .getCaptionLabel()
   .setFont(font)
   .toUpperCase(false)
   .setSize(12)
   .setText("Enter New Keyword: ")
   .getStyle().marginTop = -40;
   
  //use tag api to get image with the keyword
  getTag();
  getTagCount();
  getUserInfo();
  
}

void draw(){
  background(200);
  
  tint(#535758);
  imageMode(CORNER);
  map.draw();
  map.setZoomRange(2, 10);
  map.setTweening(true); 
  noTint();
  
  //draw text on the left side      
  for(int k=0; k<selectedTag.length; k++){
    strokeWeight(1);
    stroke(#06AED6, 80);
    fill(#06AED6, 50);
    rectMode(CORNER); 
    rect((leftMargin - rectWidth)/2, 20 + k * (rectHeight + 10), rectWidth, rectHeight);
    line((leftMargin + rectWidth)/2, 20 + k * (rectHeight + 10) + rectHeight/2, leftMargin,20 + k * (rectHeight + 10) + rectHeight/2);
    fill(#1A1A1A);
    textFont(font, 12);
    textAlign(CENTER);
    text(selectedTag[k], leftMargin/2, 35 + 30 * k);
    for(int i=0; i<count; i++){
    
      loc[i] = new Location(lat[i],lon[i]);
      pos[i] = map.getScreenPosition(loc[i]);
      
      for(int j=0; j<tagName[i].length; j++){
        if(selectedTag[k].equals(tagName[i][j]) == true && pos[i].x > leftMargin + frameLength/2 && pos[i].x < leftMargin + height - frameLength/2
           && pos[i].y > frameLength/2 && pos[i].y < height - frameLength/2){
          stroke(#06AED6, 100);
          strokeCap(ROUND);
          line(pos[i].x, pos[i].y, leftMargin, 20 + k * (rectHeight + 10) + rectHeight/2);
        }
      }
    } 
  }
  
  drawImages();
      
}

void controlEvent(ControlEvent theEvent) {
  if(theEvent.isAssignableFrom(Textfield.class)) {
    println("controlEvent: accessing a string from controller '"
            +theEvent.getName()+"': "
            +theEvent.getStringValue()
            );
  }
}

void keyPressed() {
  if (key == ' ') {
    map.zoomLevelOut();
  }
}
